package main

import (
	"crypto/rand"
	"time"
)

type Session struct {
	Id        []byte    `json:"id"`
	IdStudent int64     `json:"login"`
	Time      time.Time `json:"time"`
}

func getSession(id []byte) (s Session, err error) {
	err = DBQueryRow("SELECT id_session, id_student, time FROM student_sessions WHERE id_session=?", id).Scan(&s.Id, &s.IdStudent, &s.Time)
	return
}

func (student Student) NewSession() (Session, error) {
	session_id := make([]byte, 255)
	if _, err := rand.Read(session_id); err != nil {
		return Session{}, err
	} else if _, err := DBExec("INSERT INTO student_sessions (id_session, id_student, time) VALUES (?, ?, ?)", session_id, student.Id, time.Now()); err != nil {
		return Session{}, err
	} else {
		return Session{session_id, student.Id, time.Now()}, nil
	}
}

func (s Session) Update() (int64, error) {
	if res, err := DBExec("UPDATE student_sessions SET id_student = ?, time = ? WHERE id_session = ?", s.IdStudent, s.Time, s.Id); err != nil {
		return 0, err
	} else if nb, err := res.RowsAffected(); err != nil {
		return 0, err
	} else {
		return nb, err
	}
}

func (s Session) Delete() (int64, error) {
	if res, err := DBExec("DELETE FROM student_sessions WHERE id_session = ?", s.Id); err != nil {
		return 0, err
	} else if nb, err := res.RowsAffected(); err != nil {
		return 0, err
	} else {
		return nb, err
	}
}

func ClearSession() (int64, error) {
	if res, err := DBExec("DELETE FROM student_sessions"); err != nil {
		return 0, err
	} else if nb, err := res.RowsAffected(); err != nil {
		return 0, err
	} else {
		return nb, err
	}
}
