package main

import (
	"fmt"
	"net/http"
	"path"
	"strings"

	"github.com/julienschmidt/httprouter"
)

//go:generate go-bindata -ignore "\\.go|\\.less" -pkg "main" -o "bindata.go" htdocs/...
//go:generate go fmt bindata.go

func init() {
	Router().GET("/css/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		w.Header().Set("Content-Type", "text/css")
		if data, err := Asset(path.Join("htdocs", r.URL.Path)); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/fonts/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset(path.Join("htdocs", r.URL.Path)); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/img/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset(path.Join("htdocs", r.URL.Path)); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/js/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		w.Header().Set("Content-Type", "text/javascript")
		if data, err := Asset(path.Join("htdocs", r.URL.Path)); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/views/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		w.Header().Set("Content-Type", "text/html")
		if data, err := Asset(path.Join("htdocs", r.URL.Path)); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})

	Router().GET("/dashboard/", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/dashboard.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/dashboard/css/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		w.Header().Set("Content-Type", "text/css")
		if data, err := Asset(path.Join("htdocs", strings.TrimPrefix(r.URL.Path, "/dashboard"))); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/dashboard/js/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		w.Header().Set("Content-Type", "text/javascript")
		if data, err := Asset(path.Join("htdocs", strings.TrimPrefix(r.URL.Path, "/dashboard"))); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})

	Router().GET("/maatma/", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/maatma.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/maatma/auth", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/maatma.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/maatma/domains", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/maatma.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/maatma/tunnels", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset("htdocs/maatma.html"); err != nil {
			fmt.Fprintf(w, "{\"errmsg\":%q}", err)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/maatma/css/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		w.Header().Set("Content-Type", "text/css")
		if data, err := Asset(path.Join("htdocs", strings.TrimPrefix(r.URL.Path, "/maatma"))); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/maatma/fonts/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset(path.Join("htdocs", strings.TrimPrefix(r.URL.Path, "/maatma"))); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/maatma/img/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		if data, err := Asset(path.Join("htdocs", strings.TrimPrefix(r.URL.Path, "/maatma"))); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/maatma/js/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		w.Header().Set("Content-Type", "text/javascript")
		if data, err := Asset(path.Join("htdocs", strings.TrimPrefix(r.URL.Path, "/maatma"))); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
	Router().GET("/maatma/views/*_", func(w http.ResponseWriter, r *http.Request, ps httprouter.Params) {
		w.Header().Set("Content-Type", "text/html")
		if data, err := Asset(path.Join("htdocs", strings.TrimPrefix(r.URL.Path, "/maatma"))); err != nil {
			http.NotFound(w, r)
		} else {
			w.Write(data)
		}
	})
}
